@@ -1,6 +1,6 @@
 #
 # R3D rendering functions - rgl implementation
-# $Id: r3d.rgl.R 1113 2014-07-16 13:03:01Z murdoch $
+# $Id: r3d.rgl.R 1252 2015-06-28 05:26:12Z murdoch $
 # 
 
 # Node Management
@@ -113,12 +113,12 @@ bbox3d	    <- function(xat = NULL,
                         xunit = "pretty",
                         yunit = "pretty",
                         zunit = "pretty",
-		        expand = 1.03, nticks = 5, draw_front = FALSE, ...) {  
+		        expand = 1.03, draw_front = FALSE, ...) {  
   .check3d(); save <- material3d(); on.exit(material3d(save))
   ranges <- .getRanges(expand = expand)
   do.call("rgl.bbox", c(list(xat=xat, yat=yat, zat=zat, 
                              xunit=xunit, yunit=yunit, zunit=zunit, expand=expand,
-                             nticks=nticks, draw_front=draw_front), 
+                             draw_front=draw_front), 
                         .fixMaterialArgs(..., Params = save)))
 }
 
@@ -128,7 +128,7 @@ observer3d <- function(x, y=NULL, z=NULL, auto=FALSE) {
   else {
     xyz <- xyz.coords(x,y,z)
     location <- c(xyz$x, xyz$y, xyz$z)
-    if (length(location) != 3) stop("a single point must be specified for the observer location") 
+    if (length(location) != 3) stop("A single point must be specified for the observer location") 
   }    
   prev <- .C(rgl_getObserver, success=integer(1), ddata=numeric(3), NAOK = TRUE)$ddata
   .C(rgl_setObserver, success=as.integer(auto), ddata=as.numeric(location), NAOK = TRUE)
