@@ -77,15 +77,15 @@ mouseTrackball <- function(button = 1, dev = rgl.cur() ) {
 }
 
 mouseXAxis<- function(button = 1, dev = rgl.cur() , left=TRUE) {
-    setOneAxis(button, dev, axis=c(1,0,0), left=left) 
+    mouseOneAxis(button, dev, axis=c(1,0,0), left=left) 
 }
 
 mouseYAxis<- function(button = 1, dev = rgl.cur(), left = TRUE ) {
-    setOneAxis(button, dev, axis=c(0,1,0), left=left) 
+    mouseOneAxis(button, dev, axis=c(0,1,0), left=left) 
 }
 
 mouseZAxis<- function(button = 1, dev = rgl.cur(), left=TRUE) {
-    setOneAxis(button, dev, axis=c(0,0,1), left=left) 
+    mouseOneAxis(button, dev, axis=c(0,0,1), left=left) 
 }
 
 mouseOneAxis <- function(button = 1, dev = rgl.cur(), axis = c(1,0,0), left = TRUE ) {
@@ -292,11 +292,10 @@ mouseFOV <- function(button = 1, dev = rgl.cur())
                       init=par3d("FOV")/180, range = c(1,179)/180, direction=c(0,1))
                       
 # Synchronize mouse control of two windows for stereo view
-Example <- system.file("R-ex/surface3d.R", package="rgl")
-source(Example, echo = FALSE)
+example(surface3d, echo = FALSE)
 par3d(windowRect= c(0,32,512,544), userMatrix = rotationMatrix(5*pi/180, 0,1,0) %*% par3d("userMatrix") )
 w1 <- rgl.cur()
-source(Example, echo = FALSE)
+example(surface3d, echo = FALSE)
 par3d(windowRect = c(512,32,1024,544))
 w2 <- rgl.cur()
 mouseTrackball(dev=c(w1,w2))
