@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: api.cpp 1415 2015-11-26 20:31:02Z murdoch $
+// $Id: api.cpp 1436 2016-01-01 15:18:43Z murdoch $
 
 #include "lib.h"
 #include "DeviceManager.h"
@@ -1169,7 +1169,7 @@ void rgl::rgl_snapshot(int* successptr, int* idata, char** cdata)
   *successptr = success;
 }
 
-void rgl::rgl_pixels(int* successptr, int* ll, int* size, int* component, float* result)
+void rgl::rgl_pixels(int* successptr, int* ll, int* size, int* component, double* result)
 {
   int success = RGL_FAIL;
   
