@@ -1,7 +1,7 @@
 #ifndef RENDER_H
 #define RENDER_H
 
-#include "RenderContext.hpp"
+#include "RenderContext.h"
 
 #include "types.h"
 
